@@ -1,27 +1,23 @@
-# 
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Software-License-OrLaterPack.
-#pod
-#pod perl-Software-License-OrLaterPack is free software: you can redistribute it and/or modify it
-#pod under the terms of the GNU General Public License as published by the Free Software Foundation,
-#pod either version 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Software-License-OrLaterPack is distributed in the hope that it will be useful, but
-#pod WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-#pod PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Software-License-OrLaterPack. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
-# --------------------------------------------------------------------------------------------------
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+#
+#   file: lib/Software/License/GPL_1/or_later.pm
+#
+#   Copyright © 2015 Van de Bugger
+#
+#   This file is part of perl-Software-License-OrLaterPack.
+#
+#   perl-Software-License-OrLaterPack is free software: you can redistribute it and/or modify it
+#   under the terms of the GNU General Public License as published by the Free Software Foundation,
+#   either version 3 of the License, or (at your option) any later version.
+#
+#   perl-Software-License-OrLaterPack is distributed in the hope that it will be useful, but
+#   WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+#   PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Software-License-OrLaterPack. If not, see <http://www.gnu.org/licenses/>.
+#
+#   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #tt
 #tt
@@ -51,7 +47,7 @@
 #pod
 #pod =head1 SYNOPSIS
 #pod
-#pod     $lic = Software::License::GPL_1::or_later->new( {
+#pod     my $lic = Software::License::GPL_1::or_later->new( {
 #pod         holder  => 'John Doe',
 #pod         year    => '2010',
 #pod         program => 'Assa'
@@ -88,16 +84,16 @@ use warnings;
 use version 0.77;
 
 # ABSTRACT: GPLv1+ license for Software::License infrastructure
-our $VERSION = 'v0.10.0'; # VERSION
+our $VERSION = 'v0.10.1'; # VERSION
 
 use parent 'Software::License::GPL_1';
 use Text::Wrap;
 
-#pod =method _abbr
+#pod =attr _abbr
 #pod
-#pod Returns bare abbreviated license name, "GPL".
+#pod Bare abbreviated license name, "GPL".
 #pod
-#pod Note: this method is not inherited from base class.
+#pod Note: this attribute is I<not> inherited from the base class.
 #pod
 #pod =cut
 
@@ -105,12 +101,12 @@ sub _abbr {
     return 'GPL';
 };
 
-#pod =method abbr
+#pod =attr abbr
 #pod
-#pod Returns abbreviated license name: concatenated bare abbreviated license name, 'v' character,
-#pod and license version (with trailing plus sign).
+#pod Abbreviated license name: concatenated bare abbreviated license name, 'v' character, and license
+#pod version (with trailing plus sign).
 #pod
-#pod Note: this method is not inherited from base class.
+#pod Note: this attribute is I<not> inherited from the base class.
 #pod
 #pod =cut
 
@@ -119,11 +115,11 @@ sub abbr {
     return $self->_abbr . 'v' . $self->version;
 };
 
-#pod =method base
+#pod =attr base
 #pod
-#pod Returns a reference to base license object, i. e. license without "or later" clause.
+#pod A reference to base license object, i. e. license without "or later" clause.
 #pod
-#pod Note: this method is not inherited from base class.
+#pod Note: this attribute is I<not> inherited from the base class.
 #pod
 #pod =cut
 
@@ -136,13 +132,13 @@ sub base {
     return $self->{ base };
 };
 
-#pod =method _name
+#pod =attr _name
 #pod
-#pod Returns bare name of the license, which is also bare name of the base license, because it does
+#pod Bare name of the license, which is also bare name of the base license, because it does
 #pod include neither definitive article ("The"), nor license version nor "or later" clause:
 #pod "GNU General Public License".
 #pod
-#pod Note: this method is not inherited from base class.
+#pod Note: this attribute is I<not> inherited from the base class.
 #pod
 #pod =cut
 
@@ -150,9 +146,9 @@ sub _name {
     return 'GNU General Public License';
 };
 
-#pod =method name
+#pod =attr name
 #pod
-#pod This method meets C<Software::License> specification: returned name starts with definitive
+#pod This attribute meets C<Software::License> specification: returned name starts with definitive
 #pod capitalized article ("The"). Returned name also includes the base license version (like other
 #pod C<Software::License> classes do) (without trailing plus sign) and "or later" clause.
 #pod
@@ -163,13 +159,13 @@ sub name {
     return sprintf( "The %s version %s or later", $self->_name, $self->base->version );
 };
 
-#pod =method program
+#pod =attr program
 #pod
-#pod Returns a program name as specified by the C<program> option in constructor, or the C<Program>
-#pod option in constructor, or "this program". This form of program name is intended to be used in the
-#pod middle of sentence.
+#pod A program name as specified by the C<program> option in constructor, or the C<Program> option in
+#pod constructor, or "this program". This form of program name is intended to be used in the middle of
+#pod sentence.
 #pod
-#pod Note: this method is not inherited from base class.
+#pod Note: this attribute is I<not> inherited from the base class.
 #pod
 #pod =cut
 
@@ -178,13 +174,13 @@ sub program {
     return $self->{ program } || $self->{ Program } || 'this program';
 };
 
-#pod =method Program
+#pod =attr Program
 #pod
-#pod Returns a program name as specified by the C<Program> option in constructor, the C<program> option
-#pod in constructor, or "This program". This form of program name is intended to be used in the
-#pod beginning of sentence.
+#pod A program name as specified by the C<Program> option in constructor, or the C<program> option in
+#pod constructor, or "This program". This form of program name is intended to be used in the beginning
+#pod of sentence.
 #pod
-#pod Note: this method is not inherited from base class.
+#pod Note: this attribute is I<not> inherited from the base class.
 #pod
 #pod =cut
 
@@ -201,7 +197,7 @@ sub Program {
 #pod *   If the license object was created with C<program> or C<Program> or both options, notice will
 #pod     include real program name instead of generic "this program".
 #pod *   It returns copyright statement followed by standard GNU 3-paragraph license notice.
-#pod *   Result is formatted with L<Text::Wrap::fill>.
+#pod *   Result is formatted with L<Text::Wrap::fill|Text::Wrap>.
 #pod
 #pod The method can be called with C<'short'> argument to get short version of notice. Short version
 #pod includes: copyright statement, license name, and two sentences about free software and warranties.
@@ -218,9 +214,9 @@ sub notice {
     return $notice;
 };
 
-#pod =method version
+#pod =attr version
 #pod
-#pod Returns base license version with appended plus sign.
+#pod License version (base license version with appended plus sign to denote "or later" clause).
 #pod
 #pod =cut
 
@@ -231,6 +227,19 @@ sub version {
 
 1;
 
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
+#pod
+#pod =cut
+
 # doc/what.pod #
 
 #pod =encoding UTF-8
@@ -256,7 +265,7 @@ Software::License::GPL_1::or_later - GPLv1+ license for Software::License infras
 
 =head1 VERSION
 
-Version v0.10.0, released on 2015-10-03 09:01 UTC.
+Version v0.10.1, released on 2015-10-22 21:45 UTC.
 
 =head1 WHAT?
 
@@ -274,7 +283,7 @@ bug reporting and some others are covered in the F<README> file.
 
 =head1 SYNOPSIS
 
-    $lic = Software::License::GPL_1::or_later->new( {
+    my $lic = Software::License::GPL_1::or_later->new( {
         holder  => 'John Doe',
         year    => '2010',
         program => 'Assa'
@@ -302,56 +311,62 @@ It overrides few parent methods and introduces few own methods.
 
 See documentation on L<Software::License> for a general description of the class interface.
 
-=head1 OBJECT METHODS
+=head1 OBJECT ATTRIBUTES
 
 =head2 _abbr
 
-Returns bare abbreviated license name, "GPL".
+Bare abbreviated license name, "GPL".
 
-Note: this method is not inherited from base class.
+Note: this attribute is I<not> inherited from the base class.
 
 =head2 abbr
 
-Returns abbreviated license name: concatenated bare abbreviated license name, 'v' character,
-and license version (with trailing plus sign).
+Abbreviated license name: concatenated bare abbreviated license name, 'v' character, and license
+version (with trailing plus sign).
 
-Note: this method is not inherited from base class.
+Note: this attribute is I<not> inherited from the base class.
 
 =head2 base
 
-Returns a reference to base license object, i. e. license without "or later" clause.
+A reference to base license object, i. e. license without "or later" clause.
 
-Note: this method is not inherited from base class.
+Note: this attribute is I<not> inherited from the base class.
 
 =head2 _name
 
-Returns bare name of the license, which is also bare name of the base license, because it does
+Bare name of the license, which is also bare name of the base license, because it does
 include neither definitive article ("The"), nor license version nor "or later" clause:
 "GNU General Public License".
 
-Note: this method is not inherited from base class.
+Note: this attribute is I<not> inherited from the base class.
 
 =head2 name
 
-This method meets C<Software::License> specification: returned name starts with definitive
+This attribute meets C<Software::License> specification: returned name starts with definitive
 capitalized article ("The"). Returned name also includes the base license version (like other
 C<Software::License> classes do) (without trailing plus sign) and "or later" clause.
 
 =head2 program
 
-Returns a program name as specified by the C<program> option in constructor, or the C<Program>
-option in constructor, or "this program". This form of program name is intended to be used in the
-middle of sentence.
+A program name as specified by the C<program> option in constructor, or the C<Program> option in
+constructor, or "this program". This form of program name is intended to be used in the middle of
+sentence.
 
-Note: this method is not inherited from base class.
+Note: this attribute is I<not> inherited from the base class.
 
 =head2 Program
 
-Returns a program name as specified by the C<Program> option in constructor, the C<program> option
-in constructor, or "This program". This form of program name is intended to be used in the
-beginning of sentence.
+A program name as specified by the C<Program> option in constructor, or the C<program> option in
+constructor, or "This program". This form of program name is intended to be used in the beginning
+of sentence.
 
-Note: this method is not inherited from base class.
+Note: this attribute is I<not> inherited from the base class.
+
+=head2 version
+
+License version (base license version with appended plus sign to denote "or later" clause).
+
+=head1 OBJECT METHODS
 
 =head2 notice
 
@@ -369,7 +384,7 @@ It returns copyright statement followed by standard GNU 3-paragraph license noti
 
 =item *
 
-Result is formatted with L<Text::Wrap::fill>.
+Result is formatted with L<Text::Wrap::fill|Text::Wrap>.
 
 =back
 
@@ -377,30 +392,19 @@ The method can be called with C<'short'> argument to get short version of notice
 includes: copyright statement, license name, and two sentences about free software and warranties.
 Note: This is experimental feature.
 
-=head2 version
-
-Returns base license version with appended plus sign.
-
 =head1 AUTHOR
 
 Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015 Van de Bugger
 
-This file is part of perl-Software-License-OrLaterPack.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Software-License-OrLaterPack is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the Free Software Foundation,
-either version 3 of the License, or (at your option) any later version.
-
-perl-Software-License-OrLaterPack is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Software-License-OrLaterPack. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
 
